/* 
* Rootfly:  A program for analyzing and measuring roots. 
* Copyright (c) 2005 Clemson University.
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or (at
* your option) any later version.
* 
* This program is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* General Public License for more details.
* 
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/ 

// RootData.h: interface for the RootData class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_ROOTDATA_H__C6F0BA56_E7B4_4E66_888B_BB14E7D99F3A__INCLUDED_)
#define AFX_ROOTDATA_H__C6F0BA56_E7B4_4E66_888B_BB14E7D99F3A__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include <vector>
#include "RootOverTime.h"

//typedef std::vector<RootOverTime> RootList; // a RootList contains each root in a Window

// Modified RootList to avoid re-writing the code to access the vector, added offset_list
struct RootList
{
   std::vector<RootOverTime> m_root_list;
   std::vector<CPoint> offset_list;
   RootOverTime& at(int index);
   void resize(int size);
   unsigned int size() const;
   void RootList::push_back(const RootOverTime& root);
};

class RootData
{
public:
  RootData();
  virtual ~RootData();
  void Clear(void);
  void GetDimensions(int *ntubes, int *ntransects, int *nwindows, int *nsessions);
  void SetDimensions(int ntubes, int ntransects, int nwindows, int nsessions);
  RootList *GetRootList(int num_tube, int num_transect, int num_win);
  const RootList *GetRootList(int num_tube, int num_transect, int num_window) const;

private:
   int m_num_sessions;
   typedef std::vector<RootList> Transect; // a vector of RootList, which is basically a Window
   typedef std::vector<Transect> Tube;
   std::vector<Tube> m_data;
};

#endif // !defined(AFX_ROOTDATA_H__C6F0BA56_E7B4_4E66_888B_BB14E7D99F3A__INCLUDED_)
